# eric7.EricWidgets.EricProgressDialog

Module implementing a progress dialog allowing a customized progress bar label.

### Global Attributes

None

### Classes

EricProgressDialog | Class implementing a progress dialog allowing a customized progress bar label.

### Functions

None

## EricProgressDialog

Class implementing a progress dialog allowing a customized progress bar label.

### Derived from

QProgressDialog

### Class Attributes

None

### Class Methods

None

### Methods

EricProgressDialog | Constructor
format | Public method to get the progress bar format.
setFormat | Public method to set the progress bar format.

### Static Methods

None

#### EricProgressDialog (Constructor)

EricProgressDialog(labelText, cancelButtonText, minimum, maximum, labelFormat=None, parent=None, flags=None)

Constructor

labelText
  text of the dialog label (string)
cancelButtonText
  text of the cancel button (string)
minimum
  minimum value (integer)
maximum
  maximum value (integer)
labelFormat
  label format of the progress bar (string)
parent
  reference to the parent widget (QWidget)
flags
  window flags of the dialog (Qt.WindowFlags)

#### EricProgressDialog.format

format()

Public method to get the progress bar format.

Return:
  progress bar format (string)

#### EricProgressDialog.setFormat

setFormat(labelFormat)

Public method to set the progress bar format.

labelFormat
  progress bar format (string)

Up